<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Redakti Formo Ricevantoj");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Redakti Formo Ricevantoj");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "formo Paĝo");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Vi povas agordi pli ol unu adresaton disigante la retpoŝtoj kun komoj.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ŝparante ricevonto ...");
define('VIEW_FORM_TABLES_HEADING', "View Form Tables");
define('VIEW_FORM_TABLES_BTN', "View Form Tables");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Select a Tables to View");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
?>